Module parameter_groups

Module parameter_groups 

Modules

checkpointing
State checkpointing for parameter management

Structs

GroupManager
Helper struct for managing parameter groups
ParameterGroup
A parameter group with its own configuration
ParameterGroupConfig
Configuration for a parameter group
TruncatedSvd
Result of a truncated singular value decomposition, M ≈ U · diag(s) · Vᵀ.

Enums

ParameterConstraint
Parameter constraints that can be applied to parameter groups

Traits

GroupedOptimizer
Optimizer with parameter group support

Functions

nuclear_norm_of_matrix
Compute the nuclear norm ‖M‖_* = Σ_i σ_i(M) of a matrix.
nuclear_norm_prox
Proximal operator of the nuclear norm: prox_{t‖·‖_*}(M) = U max(S − t, 0) Vᵀ.
project_onto_nuclear_norm_ball
Project a matrix onto the nuclear-norm ball {X : ‖X‖_* ≤ max_norm}.
truncated_svd_power_iteration
Compute a truncated SVD of matrix via power iteration with deflation.