pub struct SystemProbe { /* private fields */ }Expand description
Long-lived handle onto the operating system’s resource counters.
Implementations
Sourceimpl SystemProbe
impl SystemProbe
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a probe and take the baseline refresh that later deltas are measured against.
Sourcepub fn sample(&mut self) -> ResourceUsage
pub fn sample(&mut self) -> ResourceUsage
Take a resource sample. Rates that do not yet have a usable delta are
reported as None.