pub trait SensitivityAnalyzer<F: Float> {
// Required method
fn analyze(
&mut self,
model: &dyn Fn(&Array1<F>) -> F,
bounds: &[(F, F)],
) -> Result<SensitivityIndices<F>>;
}Expand description
Trait implemented by all sensitivity-analysis algorithms in this module.
Implementors evaluate model at a number of sample points within the
rectangular domain defined by bounds and return a populated
SensitivityIndices structure.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".