Module meta_transfer
optirs_
core
0.3.2
Module meta_
transfer
Module Items
Structs
Enums
Constants
In optirs_
core::
streaming::
adaptive_
streaming
optirs_core
::
streaming
::
adaptive_streaming
Module
meta_
transfer
Structs

Domain
Adaptation
Domain adaptation state: the characteristics of the source and target domains and the resulting per-feature adaptation weights.
Transfer
Learning
Transfer learning system: stores per-source-domain experiences and replays them into a target domain, weighted by measured domain similarity.
Transfer
Metrics
Measured transfer-learning outcomes.
Enums

Transfer
Strategy
Transfer learning strategies.
Constants

MIN_
TRANSFER_
SIMILARITY
Minimum cosine similarity between domains before source experiences are replayed into the target at all. Below this, transfer is more likely to be negative than helpful, so nothing is transferred.